package HTML::Shakan::Role::Filter;
use strict;
use warnings;
use Any::Moose '::Role';

requires 'filter';

1;
